@@ -18,7 +18,7 @@ from core.event_api import (
 
 )
 
-from src.bfchain_pc_sdk.util.helper import (
+from util.helper import (
     signature_message
 )
 
