@@ -1,4 +1,4 @@
-from src.util.helper import get_pk_sk_from_mnemonic_words, get_address
+from util.helper import get_pk_sk_from_mnemonic_words, get_address
 
 
 def get_user_from_secret(secret,prefix):
